# Configuration Reference

Config files and options.

<!-- TODO: This document is a skeleton. Fill in the sections below. -->

## Configuration Files

<!-- TODO: ~/.erk/config.toml vs .erk/config.toml -->

## Global Configuration

<!-- TODO: Options in ~/.erk/config.toml -->

## Repository Configuration

<!-- TODO: Options in .erk/config.toml -->

## GitHub Planning

<!-- TODO: erk config set github_planning true/false -->

## Environment Variables

<!-- TODO: Any environment variables erk uses -->

## See Also

- [Installation](../tutorials/installation.md) - Initial configuration
- [File Location Reference](file-locations.md) - Where config files live
